@@ -21,8 +21,9 @@ from quantrocket.cli.utils.output import json_to_cli
 from quantrocket.cli.utils.stream import to_bytes
 from quantrocket.cli.utils.files import write_response_to_filepath_or_buffer
 from quantrocket.cli.utils.parse import dict_strs_to_dict, dict_to_dict_strs
+from quantrocket.utils.warn import deprecated_replaced_by
 
-def create_usstock_bundle(code, sids=None, universes=None, free=False):
+def create_usstock_bundle(code, sids=None, universes=None, free=False, data_frequency=None):
     """
     Create a Zipline bundle for US stocks.
 
@@ -35,14 +36,19 @@ def create_usstock_bundle(code, sids=None, universes=None, free=False):
         the code to assign to the bundle (lowercase alphanumerics and hyphens only)
 
     sids : list of str, optional
-        limit to these sids
+        limit to these sids (only supported for minute data bundles)
 
     universes : list of str, optional
-        limit to these universes
+        limit to these universes (only supported for minute data bundles)
 
     free : bool
         limit to free sample data
 
+    data_frequency : str, optional
+         whether to collect minute data (which also includes daily data) or only
+         daily data. Default is minute data. Possible choices: daily, minute (or
+         aliases d, m)
+
     Returns
     -------
     dict
@@ -50,15 +56,19 @@ def create_usstock_bundle(code, sids=None, universes=None, free=False):
 
     Examples
     --------
-    Create a bundle for all US stocks:
+    Create a minute data bundle for all US stocks:
 
     >>> create_usstock_bundle("usstock-1min")
 
-    Create a bundle based on a universe:
+    Create a bundle for daily data only:
+
+    >>> create_usstock_bundle("usstock-1d", data_frequency="daily")
+
+    Create a minute data bundle based on a universe:
 
     >>> create_usstock_bundle("usstock-tech-1min", universes="us-tech")
 
-    Create a bundle of free sample data:
+    Create a minute data bundle of free sample data:
 
     >>> create_usstock_bundle("usstock-free-1min", free=True)
     """
@@ -70,6 +80,8 @@ def create_usstock_bundle(code, sids=None, universes=None, free=False):
         params["universes"] = universes
     if free:
         params["free"] = free
+    if data_frequency:
+        params["data_frequency"] = data_frequency
 
     response = houston.put("/zipline/bundles/{}".format(code), params=params)
 
@@ -353,13 +365,14 @@ def _cli_get_or_set_default_bundle(bundle=None, *args, **kwargs):
     else:
         return json_to_cli(get_default_bundle, *args, **kwargs)
 
-def download_minute_file(code, filepath_or_buffer=None,
-                        start_date=None, end_date=None,
-                        universes=None, sids=None,
-                        exclude_universes=None, exclude_sids=None,
-                        times=None, fields=None):
+def download_bundle_file(code, filepath_or_buffer=None,
+                         start_date=None, end_date=None,
+                         data_frequency=None,
+                         universes=None, sids=None,
+                         exclude_universes=None, exclude_sids=None,
+                         times=None, fields=None):
     """
-    Query minute data from a Zipline bundle and download to a CSV file.
+    Query minute or daily data from a Zipline bundle and download to a CSV file.
 
     Parameters
     ----------
@@ -375,6 +388,12 @@ def download_minute_file(code, filepath_or_buffer=None,
     end_date : str (YYYY-MM-DD), optional
         limit to history on or before this date
 
+    data_frequency : str, optional
+        whether to query minute or daily data. If omitted, defaults to minute data
+        for minute bundles and to daily data for daily bundles. This parameter
+        only needs to be set to request daily data from a minute bundle. Possible
+        choices: daily, minute (or aliases d, m).
+
     universes : list of str, optional
         limit to these universes
 
@@ -402,7 +421,7 @@ def download_minute_file(code, filepath_or_buffer=None,
     --------
     Load minute prices into pandas:
 
-    >>> download_minute_file("usstock-1min", sids=["FIBBG12345"])
+    >>> download_bundle_file("usstock-1min", sids=["FIBBG12345"])
     >>> prices = pd.read_csv(f, parse_dates=["Date"], index_col=["Field","Date"])
 
     Isolate fields with .loc:
@@ -418,6 +437,8 @@ def download_minute_file(code, filepath_or_buffer=None,
         params["start_date"] = start_date
     if end_date:
         params["end_date"] = end_date
+    if data_frequency:
+        params["data_frequency"] = data_frequency
     if universes:
         params["universes"] = universes
     if sids:
@@ -438,7 +459,8 @@ def download_minute_file(code, filepath_or_buffer=None,
         houston.raise_for_status_with_json(response)
     except requests.HTTPError as e:
         # Raise a dedicated exception
-        if "no history matches the query parameters" in repr(e).lower():
+        # This endpoint returns "no minute|daily data match the query parameters"
+        if "data match the query parameters" in repr(e).lower():
             raise NoHistoricalData(e)
         raise
 
@@ -446,8 +468,13 @@ def download_minute_file(code, filepath_or_buffer=None,
 
     write_response_to_filepath_or_buffer(filepath_or_buffer, response)
 
-def _cli_download_minute_file(*args, **kwargs):
-    return json_to_cli(download_minute_file, *args, **kwargs)
+def _cli_download_bundle_file(*args, **kwargs):
+    return json_to_cli(download_bundle_file, *args, **kwargs)
+
+@deprecated_replaced_by(download_bundle_file)
+def download_minute_file(*args, **kwargs):
+    kwargs["data_frequency"] = "minute"
+    return download_bundle_file(*args, **kwargs)
 
 def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
              start_date=None, end_date=None, progress=None, filepath_or_buffer=None):
@@ -464,7 +491,8 @@ def backtest(strategy, data_frequency=None, capital_base=None, bundle=None,
         the strategy to run (strategy filename without extension)
 
     data_frequency : str, optional
-        the data frequency of the simulation. Possible choices: daily, minute (default is minute)
+        the data frequency of the simulation. Possible choices: daily, minute
+        (or aliases d, m). Default is minute.
 
     capital_base : float, optional
         the starting capital for the simulation (default is 1e6 (1 million))
@@ -591,7 +619,7 @@ def trade(strategy, bundle=None, account=None, data_frequency=None):
 
     data_frequency : str, optional
         the data frequency to use. Possible choices: daily, minute
-        (default is minute)
+        (or aliases d, m). Default is minute.
 
     Returns
     -------
